<!DOCTYPE TS><TS>
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Existe vida máis aló do navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Esta é unha edición «Proba conceptual», non agarde que sexa perfecta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Envie os seus informes de erros ou as súas ideas a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é Software libre, mais o seu desenvolvemento leva un tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Por favor, &lt;a href=&apos;%1&apos;&gt;faga unha donación a través de PayPal&lt;/a&gt; para apoiar o desenvolvemento continuo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icona deseñada por %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado baixo a &lt;a href=&apos;%1&apos;&gt;Licenza pública Xeral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Pechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>O que vostede sempre quixo saber sobre %1 e nunca se atreveu a preguntar</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto aportado por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Compatibilidade con proxy HTTP aportado por %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">A versión Windows foi construida por %1</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Faga unha &lt;a href=&apos;%1&apos;&gt;donación&lt;/a&gt; para axudar na continuación do desenvolvemento de %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restantes</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%n Download(s)</source>
        <translation>%n Descarga(s)
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Isto é só a versión demo de %1.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Só se poden descargar videos curtos de menos de %1 minutos para que poida probar a utilidade de descargas.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versión completa</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar a localización...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escolla a localización da descarga</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Cambiada a localización da descarga.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>A descarga actual aínda se fai na localización anterior.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Descargando en: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/deter</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar a reprodución despois da pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Seguinte pista</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Buscar cara adiante</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Buscar cara atrás</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 máis</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Non hai vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Non hai máis vídeos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Atrás</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Left</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Ir para a vista anterior</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Parara a reprodución e volver á vista de busca</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar ao seguinte vídeo</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+Right</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Deter</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Detera reprodución</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Barra de espaço</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir á pantalla completa</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Abrir a páxina do vídeo en YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Retirar os videos seleccionados da lista de reprodución</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover cara &amp;arriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover cara arriba os vídeos selecionados na lista de reprodución</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+Up</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover cara a&amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover cara abaixo os vídeos selecionados na lista de reprodución</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+Down</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Saír</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Deica logo</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube na Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Doar ao través de PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoie o desenvolvemento continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información acerca de %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Pesquisar</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicativo</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reprodución</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;xuda</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar a reprodución</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Saír de &amp;pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Agochar a lista de reprodución e a barra de tarefas</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume ao %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>O volume está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>O volume non está silenciado</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar o volume</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prema %1 para aumentar o volume, %2 para diminuilo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">O vídeo en alta definición está activado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">O vídeo en alta definición non está activado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">O vídeo actual é de alta definición</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">O vídeo actual non é de alta definición</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Limpar palabras &amp;clave recentes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpar o historial de buscas. Non se pode desfacer.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>A súa intimidade agora está segura</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Abrir a páxina de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir á páxina de vídeos YouTube e pausar a reprodución</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar a &amp;ligazón de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar a ligazón actual de vídeo de YouTube no portaretallos</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar o &amp;URL de fluxo de vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar o URL actual do fluxo de vídeo no portaretallos</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Facer unha &amp;donación</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolución máxima de vídeo fixada en %1</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostrar os detalles sobre as descargas de vídeo</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descarga</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Descargando o vídeo actual</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Desexa saír de %1 cunha descarga en proceso?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Se pecha %1 agora, esta descarga vai seren cancelada.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Pechar e cancelar a descarga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Agardar a que remate a descarga</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descargas complatadas</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Máis destacados</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Máis recentes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Máis vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">Está a ver &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Agora pode pegar a ligazón de YouTube noutro aplicativo</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Agora pode pegar o URL do fluxo de vídeo noutro aplicativo</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>A ligazón ten validez só por un tempo limitado.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Isto é só a versión demo de %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Permítelle probar o aplicativo e comprobar se vai ao seu xeito.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versión completa</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descargando %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Produciuse un erro na rede: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizacións</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Produciuse un fallo</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completada</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Detida</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Deter a descarga</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostrar en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir o cartafol pai</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reiniciar a descarga</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">Escriba unha palabra clave para comezar a ver os vídeos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palabra clave recente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Está dispoñíbel unha nova versión de %1. Por favor, &lt;a href=&apos;%2&apos;&gt;actualice cara a versión %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Síntase cómodo</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versión completa</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Introduza</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>unha palabra clave</translation>
    </message>
    <message>
        <source>a channel</source>
        <translation>un canle</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>para comezar a ver vídeos.</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canles recentes</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opções de &amp;vídeo</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation>Empregar vídeo en alta calidade cando estea dispoñíbel</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;salvas recentemente</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Palavras-chave &amp;limpas recentemente</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erro na rede: %1 por %2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Non é posíbel obter o fluxo de vídeo de %1</translation>
    </message>
</context>
</TS>
